Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1151)

Unified Diff: net/quic/quic_sent_packet_manager.h

Issue 849123003: Land Recent QUIC Changes. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Removed extra blank line Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/quic/quic_protocol.cc ('k') | net/quic/quic_sent_packet_manager.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/quic/quic_sent_packet_manager.h
diff --git a/net/quic/quic_sent_packet_manager.h b/net/quic/quic_sent_packet_manager.h
index 287b5fc44ad30ed608224782d85b194773636c71..f1ebe87e0fa417b69d997a0acd530e0c9b93c4d6 100644
--- a/net/quic/quic_sent_packet_manager.h
+++ b/net/quic/quic_sent_packet_manager.h
@@ -48,7 +48,7 @@ class NET_EXPORT_PRIVATE QuicSentPacketManager {
virtual ~DebugDelegate() {}
// Called when a spurious retransmission is detected.
- virtual void OnSpuriousPacketRetransmition(
+ virtual void OnSpuriousPacketRetransmission(
TransmissionType transmission_type,
QuicByteCount byte_size) {}
@@ -217,6 +217,9 @@ class NET_EXPORT_PRIVATE QuicSentPacketManager {
// start threshold and will return 0.
QuicPacketCount GetSlowStartThresholdInTcpMss() const;
+ // Called by the connection every time it receives a serialized packet.
+ void OnSerializedPacket(const SerializedPacket& serialized_packet);
+
// Enables pacing if it has not already been enabled.
void EnablePacing();
@@ -287,6 +290,10 @@ class NET_EXPORT_PRIVATE QuicSentPacketManager {
// Retransmits all crypto stream packets.
void RetransmitCryptoPackets();
+ // Retransmits two packets for an RTO and removes any non-retransmittable
+ // packets from flight.
+ void RetransmitRtoPackets();
+
// Retransmits all the packets and abandons by invoking a full RTO.
void RetransmitAllPackets();
@@ -390,7 +397,7 @@ class NET_EXPORT_PRIVATE QuicSentPacketManager {
size_t consecutive_tlp_count_;
// Number of times the crypto handshake has been retransmitted.
size_t consecutive_crypto_retransmission_count_;
// Number of pending transmissions of TLP or crypto packets.
size_t pending_timer_transmission_count_;
// Maximum number of tail loss probes to send before firing an RTO.
size_t max_tail_loss_probes_;
@@ -390,7 +397,7 @@ class NET_EXPORT_PRIVATE QuicSentPacketManager {
// Number of times the crypto handshake has been retransmitted.
size_t consecutive_crypto_retransmission_count_;
- // Number of pending transmissions of TLP or crypto packets.
+ // Number of pending transmissions of TLP, RTO, or crypto packets.
size_t pending_timer_transmission_count_;
// Maximum number of tail loss probes to send before firing an RTO.
« no previous file with comments | « net/quic/quic_protocol.cc ('k') | net/quic/quic_sent_packet_manager.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698